@@ -19,11 +19,14 @@ from .parser import create_parser, preprocess_args
 from .utils import ensure_directories, setup_logging
 from .commands import (
     run_session,
-    list_tickets,
+    manage_tickets,
     show_info,
     manage_agents,
     manage_memory,
-    manage_monitor
+    manage_monitor,
+    manage_config,
+    aggregate_command,
+    cleanup_memory
 )
 from claude_mpm.config.paths import paths
 
@@ -176,11 +179,14 @@ def _execute_command(command: str, args) -> int:
     # Map commands to their implementations
     command_map = {
         CLICommands.RUN.value: run_session,
-        CLICommands.TICKETS.value: list_tickets,
+        CLICommands.TICKETS.value: manage_tickets,
         CLICommands.INFO.value: show_info,
         CLICommands.AGENTS.value: manage_agents,
         CLICommands.MEMORY.value: manage_memory,
         CLICommands.MONITOR.value: manage_monitor,
+        CLICommands.CONFIG.value: manage_config,
+        CLICommands.AGGREGATE.value: aggregate_command,
+        CLICommands.CLEANUP.value: cleanup_memory,
     }
     
     # Execute command if found
