@@ -6,17 +6,24 @@ separate modules for better maintainability and code organization.
 """
 
 from .run import run_session
-from .tickets import list_tickets
+from .tickets import manage_tickets, list_tickets
 from .info import show_info
 from .agents import manage_agents
 from .memory import manage_memory
 from .monitor import manage_monitor
+from .config import manage_config
+from .aggregate import aggregate_command
+from .cleanup import cleanup_memory
 
 __all__ = [
     'run_session',
+    'manage_tickets',
     'list_tickets',
     'show_info',
     'manage_agents',
     'manage_memory',
-    'manage_monitor'
+    'manage_monitor',
+    'manage_config',
+    'aggregate_command',
+    'cleanup_memory'
 ]
\ No newline at end of file
