@@ -14,7 +14,7 @@ import argparse
 from pathlib import Path
 from typing import Optional, List
 
-from ..constants import CLICommands, CLIPrefix, AgentCommands, MemoryCommands, MonitorCommands, LogLevel
+from ..constants import CLICommands, CLIPrefix, AgentCommands, MemoryCommands, MonitorCommands, LogLevel, ConfigCommands, AggregateCommands, TicketCommands
 
 
 def add_common_arguments(parser: argparse.ArgumentParser, version: str = None) -> None:
@@ -127,6 +127,30 @@ def add_run_arguments(parser: argparse.ArgumentParser) -> None:
         help="Resume a session (last session if no ID specified, or specific session ID)"
     )
     
+    # Dependency checking options
+    dep_group = parser.add_argument_group('dependency options')
+    dep_group.add_argument(
+        "--no-check-dependencies",
+        action="store_false",
+        dest="check_dependencies",
+        help="Skip agent dependency checking at startup"
+    )
+    dep_group.add_argument(
+        "--force-check-dependencies",
+        action="store_true",
+        help="Force dependency checking even if cached results exist"
+    )
+    dep_group.add_argument(
+        "--no-prompt",
+        action="store_true",
+        help="Never prompt for dependency installation (non-interactive mode)"
+    )
+    dep_group.add_argument(
+        "--force-prompt",
+        action="store_true",
+        help="Force interactive prompting even in non-TTY environments (use with caution)"
+    )
+    
     # Input/output options
     io_group = parser.add_argument_group('input/output options')
     io_group.add_argument(
@@ -228,6 +252,35 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
         const="last",
         help="Resume a session (last session if no ID specified, or specific session ID)"
     )
+    run_group.add_argument(
+        "--force",
+        action="store_true",
+        help="Force operations even with warnings (e.g., large .claude.json file)"
+    )
+    
+    # Dependency checking options (for backward compatibility at top level)
+    dep_group_top = parser.add_argument_group('dependency options (when no command specified)')
+    dep_group_top.add_argument(
+        "--no-check-dependencies",
+        action="store_false",
+        dest="check_dependencies",
+        help="Skip agent dependency checking at startup"
+    )
+    dep_group_top.add_argument(
+        "--force-check-dependencies",
+        action="store_true",
+        help="Force dependency checking even if cached results exist"
+    )
+    dep_group_top.add_argument(
+        "--no-prompt",
+        action="store_true",
+        help="Never prompt for dependency installation (non-interactive mode)"
+    )
+    dep_group_top.add_argument(
+        "--force-prompt",
+        action="store_true",
+        help="Force interactive prompting even in non-TTY environments (use with caution)"
+    )
     
     # Input/output options
     io_group = parser.add_argument_group('input/output options (when no command specified)')
@@ -258,17 +311,229 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
     add_common_arguments(run_parser)
     add_run_arguments(run_parser)
     
-    # Tickets command
+    # Tickets command with subcommands
     tickets_parser = subparsers.add_parser(
         CLICommands.TICKETS.value,
-        help="List recent tickets"
+        help="Manage tickets and tracking"
     )
     add_common_arguments(tickets_parser)
-    tickets_parser.add_argument(
+    
+    tickets_subparsers = tickets_parser.add_subparsers(
+        dest="tickets_command",
+        help="Ticket commands",
+        metavar="SUBCOMMAND"
+    )
+    
+    # Create ticket
+    create_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.CREATE.value,
+        help="Create a new ticket"
+    )
+    create_ticket_parser.add_argument(
+        "title",
+        help="Ticket title"
+    )
+    create_ticket_parser.add_argument(
+        "-t", "--type",
+        default="task",
+        choices=["task", "bug", "feature", "issue", "epic"],
+        help="Ticket type (default: task)"
+    )
+    create_ticket_parser.add_argument(
+        "-p", "--priority",
+        default="medium",
+        choices=["low", "medium", "high", "critical"],
+        help="Priority level (default: medium)"
+    )
+    create_ticket_parser.add_argument(
+        "-d", "--description",
+        nargs="*",
+        help="Ticket description"
+    )
+    create_ticket_parser.add_argument(
+        "--tags",
+        help="Comma-separated tags"
+    )
+    create_ticket_parser.add_argument(
+        "--parent-epic",
+        help="Parent epic ID"
+    )
+    create_ticket_parser.add_argument(
+        "--parent-issue",
+        help="Parent issue ID"
+    )
+    create_ticket_parser.add_argument(
+        "-v", "--verbose",
+        action="store_true",
+        help="Verbose output"
+    )
+    
+    # List tickets
+    list_tickets_parser = tickets_subparsers.add_parser(
+        TicketCommands.LIST.value,
+        help="List recent tickets"
+    )
+    list_tickets_parser.add_argument(
         "-n", "--limit",
         type=int,
         default=10,
-        help="Number of tickets to show"
+        help="Number of tickets to show (default: 10)"
+    )
+    list_tickets_parser.add_argument(
+        "--type",
+        choices=["task", "bug", "feature", "issue", "epic", "all"],
+        default="all",
+        help="Filter by ticket type"
+    )
+    list_tickets_parser.add_argument(
+        "--status",
+        choices=["open", "in_progress", "done", "closed", "blocked", "all"],
+        default="all",
+        help="Filter by status"
+    )
+    list_tickets_parser.add_argument(
+        "-v", "--verbose",
+        action="store_true",
+        help="Show detailed ticket information"
+    )
+    
+    # View ticket
+    view_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.VIEW.value,
+        help="View a specific ticket"
+    )
+    view_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID (e.g., TSK-0001)"
+    )
+    view_ticket_parser.add_argument(
+        "-v", "--verbose",
+        action="store_true",
+        help="Show metadata and full details"
+    )
+    
+    # Update ticket
+    update_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.UPDATE.value,
+        help="Update a ticket"
+    )
+    update_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID"
+    )
+    update_ticket_parser.add_argument(
+        "-s", "--status",
+        choices=["open", "in_progress", "done", "closed", "blocked"],
+        help="Update status"
+    )
+    update_ticket_parser.add_argument(
+        "-p", "--priority",
+        choices=["low", "medium", "high", "critical"],
+        help="Update priority"
+    )
+    update_ticket_parser.add_argument(
+        "-a", "--assign",
+        help="Assign to user"
+    )
+    update_ticket_parser.add_argument(
+        "--tags",
+        help="Update tags (comma-separated)"
+    )
+    update_ticket_parser.add_argument(
+        "-d", "--description",
+        nargs="*",
+        help="Update description"
+    )
+    
+    # Close ticket
+    close_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.CLOSE.value,
+        help="Close a ticket"
+    )
+    close_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID"
+    )
+    close_ticket_parser.add_argument(
+        "--resolution",
+        help="Resolution description"
+    )
+    
+    # Delete ticket
+    delete_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.DELETE.value,
+        help="Delete a ticket"
+    )
+    delete_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID"
+    )
+    delete_ticket_parser.add_argument(
+        "--force",
+        action="store_true",
+        help="Force deletion without confirmation"
+    )
+    
+    # Search tickets
+    search_tickets_parser = tickets_subparsers.add_parser(
+        TicketCommands.SEARCH.value,
+        help="Search tickets"
+    )
+    search_tickets_parser.add_argument(
+        "query",
+        help="Search query"
+    )
+    search_tickets_parser.add_argument(
+        "--type",
+        choices=["task", "bug", "feature", "issue", "epic", "all"],
+        default="all",
+        help="Filter by ticket type"
+    )
+    search_tickets_parser.add_argument(
+        "--status",
+        choices=["open", "in_progress", "done", "closed", "blocked", "all"],
+        default="all",
+        help="Filter by status"
+    )
+    search_tickets_parser.add_argument(
+        "-n", "--limit",
+        type=int,
+        default=20,
+        help="Maximum results to show"
+    )
+    
+    # Add comment to ticket
+    comment_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.COMMENT.value,
+        help="Add comment to a ticket"
+    )
+    comment_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID"
+    )
+    comment_ticket_parser.add_argument(
+        "comment",
+        nargs="+",
+        help="Comment text"
+    )
+    
+    # Update workflow state
+    workflow_ticket_parser = tickets_subparsers.add_parser(
+        TicketCommands.WORKFLOW.value,
+        help="Update ticket workflow state"
+    )
+    workflow_ticket_parser.add_argument(
+        "id",
+        help="Ticket ID"
+    )
+    workflow_ticket_parser.add_argument(
+        "state",
+        choices=["todo", "in_progress", "ready", "tested", "done", "blocked"],
+        help="New workflow state"
+    )
+    workflow_ticket_parser.add_argument(
+        "--comment",
+        help="Optional comment for the transition"
     )
     
     # Info command
@@ -353,6 +618,11 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
         type=Path,
         help="Target directory (default: .claude/agents/)"
     )
+    deploy_agents_parser.add_argument(
+        "--include-all",
+        action="store_true",
+        help="Include all agents, overriding exclusion configuration"
+    )
     
     # Force deploy agents
     force_deploy_parser = agents_subparsers.add_parser(
@@ -364,6 +634,11 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
         type=Path,
         help="Target directory (default: .claude/agents/)"
     )
+    force_deploy_parser.add_argument(
+        "--include-all",
+        action="store_true",
+        help="Include all agents, overriding exclusion configuration"
+    )
     
     # Clean agents
     clean_agents_parser = agents_subparsers.add_parser(
@@ -504,6 +779,130 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
         help="Output raw memory content in JSON format for programmatic processing"
     )
     
+    # Add dependency management subcommands to agents
+    deps_check_parser = agents_subparsers.add_parser(
+        'deps-check',
+        help='Check dependencies for deployed agents'
+    )
+    deps_check_parser.add_argument(
+        '--verbose',
+        action='store_true',
+        help='Enable verbose output'
+    )
+    deps_check_parser.add_argument(
+        '--agent',
+        type=str,
+        help='Check dependencies for a specific agent only'
+    )
+    
+    deps_install_parser = agents_subparsers.add_parser(
+        'deps-install',
+        help='Install missing dependencies for deployed agents'
+    )
+    deps_install_parser.add_argument(
+        '--agent',
+        type=str,
+        help='Install dependencies for a specific agent only'
+    )
+    deps_install_parser.add_argument(
+        '--dry-run',
+        action='store_true',
+        help='Show what would be installed without actually installing'
+    )
+    
+    deps_list_parser = agents_subparsers.add_parser(
+        'deps-list',
+        help='List all dependencies from deployed agents'
+    )
+    deps_list_parser.add_argument(
+        '--format',
+        choices=['text', 'pip', 'json'],
+        default='text',
+        help='Output format for dependency list'
+    )
+    
+    deps_fix_parser = agents_subparsers.add_parser(
+        'deps-fix',
+        help='Fix missing agent dependencies with robust retry logic'
+    )
+    deps_fix_parser.add_argument(
+        '--max-retries',
+        type=int,
+        default=3,
+        help='Maximum retry attempts per package (default: 3)'
+    )
+    
+    # Config command with subcommands
+    config_parser = subparsers.add_parser(
+        CLICommands.CONFIG.value,
+        help="Validate and manage configuration"
+    )
+    add_common_arguments(config_parser)
+    
+    config_subparsers = config_parser.add_subparsers(
+        dest="config_command",
+        help="Config commands",
+        metavar="SUBCOMMAND"
+    )
+    
+    # Validate config
+    validate_config_parser = config_subparsers.add_parser(
+        ConfigCommands.VALIDATE.value,
+        help="Validate configuration file"
+    )
+    validate_config_parser.add_argument(
+        "--config-file",
+        type=Path,
+        help="Path to configuration file (default: .claude-mpm/configuration.yaml)"
+    )
+    validate_config_parser.add_argument(
+        "--strict",
+        action="store_true",
+        help="Treat warnings as errors"
+    )
+    
+    # View config
+    view_config_parser = config_subparsers.add_parser(
+        ConfigCommands.VIEW.value,
+        help="View current configuration"
+    )
+    view_config_parser.add_argument(
+        "--config-file",
+        type=Path,
+        help="Path to configuration file"
+    )
+    view_config_parser.add_argument(
+        "--section",
+        help="View specific configuration section"
+    )
+    view_config_parser.add_argument(
+        "--format",
+        choices=["table", "json", "yaml"],
+        default="table",
+        help="Output format (default: table)"
+    )
+    
+    # Config status
+    status_config_parser = config_subparsers.add_parser(
+        ConfigCommands.STATUS.value,
+        help="Show configuration status and health"
+    )
+    status_config_parser.add_argument(
+        "--config-file",
+        type=Path,
+        help="Path to configuration file"
+    )
+    status_config_parser.add_argument(
+        "--check-response-logging",
+        action="store_true",
+        help="Show detailed response logging configuration"
+    )
+    status_config_parser.add_argument(
+        "--verbose",
+        action="store_true",
+        help="Show detailed errors and warnings"
+    )
+    
     # Monitor command with subcommands
     monitor_parser = subparsers.add_parser(
         CLICommands.MONITOR.value,
@@ -572,6 +971,14 @@ def create_parser(prog_name: str = "claude-mpm", version: str = "0.0.0") -> argp
         help="Host to bind to (default: localhost)"
     )
     
+    # Import and add aggregate command parser
+    from .commands.aggregate import add_aggregate_parser
+    add_aggregate_parser(subparsers)
+    
+    # Import and add cleanup command parser
+    from .commands.cleanup import add_cleanup_parser
+    add_cleanup_parser(subparsers)
+    
     return parser
 
 
