@@ -28,6 +28,9 @@ class CLICommands(str, Enum):
     AGENTS = "agents"
     MEMORY = "memory"
     MONITOR = "monitor"
+    CONFIG = "config"
+    AGGREGATE = "aggregate"
+    CLEANUP = "cleanup-memory"
     
     def with_prefix(self, prefix: CLIPrefix = CLIPrefix.MPM) -> str:
         """Get command with prefix."""
@@ -80,6 +83,36 @@ class MonitorCommands(str, Enum):
     PORT = "port"
 
 
+class ConfigCommands(str, Enum):
+    """Config subcommand constants."""
+    VALIDATE = "validate"
+    VIEW = "view"
+    STATUS = "status"
+
+
+class AggregateCommands(str, Enum):
+    """Event aggregator subcommand constants."""
+    START = "start"
+    STOP = "stop"
+    STATUS = "status"
+    SESSIONS = "sessions"
+    VIEW = "view"
+    EXPORT = "export"
+
+
+class TicketCommands(str, Enum):
+    """Ticket subcommand constants."""
+    CREATE = "create"
+    LIST = "list"
+    VIEW = "view"
+    UPDATE = "update"
+    DELETE = "delete"
+    CLOSE = "close"
+    SEARCH = "search"
+    COMMENT = "comment"
+    WORKFLOW = "workflow"
+
+
 class CLIFlags(str, Enum):
     """CLI flag constants (without prefix)."""
     # Logging flags
